Tenks
=====

.. image:: https://governance.openstack.org/badges/metalsmith.svg
    :target: https://governance.openstack.org/reference/tags/index.html

Tenks is a utility that manages virtual bare metal clusters for development and
testing purposes. It offers:

* Declarative definition of clusters using Ansible's familiar YAML
  syntax

* Automated creation and deletion of virtualised bare metal nodes across any
  number of hypervisors

* In-built management of Open vSwitch bridges for physical networks

* Registration of nodes and ports with OpenStack Ironic, and creation of
  OpenStack Nova flavors

* Simple cluster reconfiguration and tear-down

To get started with Tenks, see the documentation (linked below).

* License: Apache License, Version 2.0
* Documentation: https://docs.openstack.org/tenks/
* Source: https://opendev.org/openstack/tenks/
* Bugs: https://storyboard.openstack.org/#!/project/openstack/tenks
* Known issues/limitations: refer to the documentation.
